@@ -148,7 +148,7 @@ Chake.nodes.each do |node|
     rsync_excludes << '--exclude' << 'nodes/'
     rsync_excludes << '--exclude' << 'local-mode-cache/'
 
-    rsync = node.rsync + ['-ap'] + ENV.fetch('CHAKE_RSYNC_OPTIONS', '').split
+    rsync = node.rsync_cmd + ['-ap'] + ENV.fetch('CHAKE_RSYNC_OPTIONS', '').split
     rsync_logging = (Rake.application.options.trace && '--verbose') || '--quiet'
 
     hash_files = Dir.glob(File.join(Chake.tmpdir, '*.sha1sum'))
@@ -211,7 +211,7 @@ Chake.nodes.each do |node|
 
   desc 'checks connectivity and setup on all nodes'
   task "check:#{hostname}" => [:connect_common, "connect:#{hostname}"] do
-    node.run('sudo echo OK')
+    node.run_as_root('echo OK')
   end
 
   # needs to be overridden in user projects
@@ -284,7 +284,7 @@ desc 'checks connectivity and setup on all nodes'
 multitask check: (Chake.nodes.map { |node| "check:#{node.hostname}" }) do
   puts '✓ all hosts OK'
   puts '  - ssh connection works'
-  puts '  - password-less sudo works'
+  puts '  - password-less sudo (if needed) works'
 end
 
 desc 'runs a Ruby console in the chake environment'
