@@ -9,7 +9,7 @@ module Chake
         "#{ssh_target}:"
       end
 
-      def rsync
+      def rsync_cmd
         [ssh_prefix, 'rsync', rsync_ssh].flatten.compact
       end
 
